%% Formation analyse de series organisee par Ingrid Puillat et Dhouha Kbaier
% Lieu: Ifremer, Brest, France
% Dates: Mercredi 27 et Jeudi 28 Mai 2015 (Session1); puis Mercredi 3 et Jeudi 4 Juin 2015 (Session 2)
% Auteur: Dhouha Kbaier Ben Ismail
% e-mail: dhouha.kbaier@ifremer.fr
% Stationnarity tests

%% Stationnarity Augmented Dickey-Fuller test adftest()--> Econometrics
% Toolbox et adf --> Spatial Econometrics

clear all;
close all;
global x_data;
global y_data;


%% Tlcharger vos donnes ici (remplacer le code pour les 3 lignes suivantes)

% load('resume_ADCP_total_rotation.mat')
% x_data=ADCP(4).date;
% y_data=ADCP(4).u(:,2);

% load('Pascal_TS.mat');
% x_data=date;
% y_data=ti(:,1);

load('load_donnes_Marel.mat')
time1=timeTemp;time2=timeSali;time3=timeSeaLevel;time4=timeTurbi;
data1=Temp;data2=Sali;data3=SeaLevel;data4=Turbi;
x_data=time3(~isnan(data3));
y_data=data3(~isnan(data3));

%% Determiner nlag-max
% Schwert (1989): "Test for Unit Roots: A Monte Carlo Investigation"
T=length(y_data);
nlagmin=floor(4*((T/100)^(1/4)));
nlagmax=floor(12*((T/100)^(1/4)));
count=nlagmax-nlagmin+1;

%% Test de la tendance
[h,pValue,stat,cValue,reg] = adftest(y_data,'model','TS','lags',nlagmin:nlagmax) ;% alpha=0.05 (default value)
% initialisation
minAIC=reg(1).AIC;
minBIC=reg(1).BIC;
lag_AIC=nlagmin;
lag_BIC=nlagmin; 
% recherche du minimun AIC et BIC pour le modele TS
for i=2:count
    if(reg(i).AIC<minAIC)
        minAIC=reg(i).AIC;
        lag_AIC=nlagmin+i-1;
    end
    if(reg(i).BIC<minBIC)
        minBIC=reg(i).BIC;
        lag_BIC=nlagmin+i-1;
    end
end

figure
x_axis=nlagmin:nlagmax;
y_axis_aic=ones(1,nlagmax-nlagmin+1);
y_axis_bic=ones(1,nlagmax-nlagmin+1);
for i=1:length(y_axis_aic)
    y_axis_aic(i)=reg(i).AIC;
    y_axis_bic(i)=reg(i).BIC;
end

plot(x_axis,y_axis_aic,'--b*',x_axis,y_axis_bic,'--r*');
% set(gca, 'xtick',nlagmin:nlagmax); 
title('{\bf AIC and BIC for Model: Trend Stationary}') 
xlabel ('{\bf model order}') 
ylabel ('{\bf model selection criterions}') 
legend('AIC','BIC','location','northEast')

%% Tests des racines unitaires
[h,pValue,stat,cValue,reg] = adftest(y_data,'model','ARD','lags',nlagmin:nlagmax) ;
% recherche du minimun AIC et BIC pour le modele ARD
for i=1:count
    if(reg(i).AIC<minAIC)
        minAIC=reg(i).AIC;
        lag_AIC=nlagmin+i-1;
    end
    if(reg(i).BIC<minBIC)
        minBIC=reg(i).BIC;
        lag_BIC=nlagmin+i-1;
    end
end
figure
x_axis=nlagmin:nlagmax;
y_axis_aic=ones(1,nlagmax-nlagmin+1);
y_axis_bic=ones(1,nlagmax-nlagmin+1);
for i=1:length(y_axis_aic)
    y_axis_aic(i)=reg(i).AIC;
    y_axis_bic(i)=reg(i).BIC;
end

plot(x_axis,y_axis_aic,'--b*',x_axis,y_axis_bic,'--r*');
%set(gca, 'xtick',nlagmin:nlagmax); 
title('{\bf AIC and BIC for Model: AutoRegressive with Drift}') 
xlabel ('{\bf model order}') 
ylabel ('{\bf model selection criterions}') 
legend('AIC','BIC','location','northEast')

[h,pValue,stat,cValue,reg] = adftest(y_data,'model','AR','lags',nlagmin:nlagmax) ;
% recherche du minimun AIC et BIC pour le modele AR
for i=1:count
    if(reg(i).AIC<minAIC)
        minAIC=reg(i).AIC;
        lag_AIC=nlagmin+i-1;
    end
    if(reg(i).BIC<minBIC)
        minBIC=reg(i).BIC;
        lag_BIC=nlagmin+i-1;
    end
end

if( lag_BIC<lag_AIC)
    lag_optimal=lag_BIC;
else
    lag_optimal=lag_AIC;
end

figure
x_axis=nlagmin:nlagmax;
y_axis_aic=ones(1,nlagmax-nlagmin+1);
y_axis_bic=ones(1,nlagmax-nlagmin+1);
for i=1:length(y_axis_aic)
    y_axis_aic(i)=reg(i).AIC;
    y_axis_bic(i)=reg(i).BIC;
end

plot(x_axis,y_axis_aic,'--b*',x_axis,y_axis_bic,'--r*');
%set(gca, 'xtick',nlagmin:nlagmax); 
title('{\bf AIC and BIC for Model: AutoRegressive}') 
xlabel ('{\bf model order}') 
ylabel ('{\bf model selection criterions}') 
legend('AIC','BIC','location','northEast')

display([ 'min AIC = ' num2str(minAIC) ' for lag =' num2str(lag_AIC)]);
display([ 'min BIC = ' num2str(minBIC) ' for lag =' num2str(lag_BIC)]);  
if(lag_optimal>1)
    display(['Please run ADF tests with the optimal lag = ' num2str(lag_optimal)]);  
else
    display(['Please run simple DF tests with the optimal lag = ' num2str(lag_optimal)]);  
end

display('adftest() function: ADF tests with for model TS');  
[h,pValue,stat,cValue,reg] = adftest(y_data,'model','TS','lags',lag_optimal) 
display(['adftest() function: ADF tests with for model ARD']);  
[h,pValue,stat,cValue,reg] = adftest(y_data,'model','ARD','lags',lag_optimal) 
display(['adftest() function: ADF tests with for model AR']);  
[h,pValue,stat,cValue,reg] = adftest(y_data,'model','AR','lags',lag_optimal) 

display('adf() function (Spatial Econometrics) : ADF tests for the three models');  
 for p=-1:1
        res = adf(y_data,p,lag_optimal);
        display(['****************************************  p= ' num2str(p) '***************************************']);
        prt(res);
 end;