function y = binocdf(x,n,p,tail)
%MATLAB Code Generation Library Function

%   Copyright 1984-2013 The MathWorks, Inc.
%#codegen

coder.internal.assert(nargin >= 3,'stats:binocdf:TooFewInputs');
validateattributes(x,{'numeric'},{'real'},'binocdf','x',1); %#ok<EMCA>
validateattributes(n,{'numeric'},{'real'},'binocdf','n',2); %#ok<EMCA>
validateattributes(p,{'single','double'},{'real'},'binocdf','p',3); %#ok<EMCA>
if nargin < 4
    upper = false;
else
    coder.internal.prefer_const(tail);
    upper = CheckForUpper(tail);
end
y = coder.internal.sxalloc([isfloat(x),isfloat(n),true],x,n,p);
ZERO = zeros(class(y));
for k = 1:numel(y)
    xk = cast(eml_scalexp_subsref(x,k),class(y));
    nk = cast(eml_scalexp_subsref(n,k),class(y));
    pk = eml_scalexp_subsref(p,k);
    if pk >= 0 && pk <= 1 && nk == floor(nk) && ~isnan(xk)
        if upper
            xk = nk - 1 - floor(xk);
            pk = 1 - pk;
        end
        if xk >= nk
            y(k) = 1;
        elseif pk == 0 && xk >= 0
            y(k) = 1;
        elseif pk == 1
            y(k) = (xk >= nk);
        elseif xk >= 0
            xf = floor(xk);
            smallp = 1e-4;
            bign = 1e5;
            np = nk*pk;
            if nk < bign
                if xk <= np || pk < smallp
                    y(k) = sumfrom(ZERO,xf,nk,pk);
                else
                    y(k) = 1 - sumfrom(ZERO,nk-xf-1,nk,1-pk);
                end
            else
                y(k) = sumA2B(xf,nk,pk);
            end
        else
            y(k) = 0;
        end
    else
        y(k) = coder.internal.nan(class(y));
    end
end

%--------------------------------------------------------------------------

function y = sumfrom(x1,x2,n,p)
% sum series starting from x1 to x2.
y = zeros(class(x1));
for j = x1:x2
    y = y + binopdf(j,n,p);
end
% Prevent roundoff error from resulting in a value larger than 1.
if y > 1
    y(1) = 1;
end

%--------------------------------------------------------------------------

function y = sumA2B(x,n,p)
% Sum series from 0 to x with optimizations to avoid negligible terms.
cls = class(x);
ZERO = zeros(cls);
ONE = ones(cls);
mu = n*p;
sd = sqrt(n*p*(1-p));
% Scan forward from mu to find x2 such that binopdf(x2,n,p) == 0.
t2 = cast(10,cls);
x2 = cast(ceil(mu + t2*sd),cls);
while x <= x2 && binopdf(x2,n,p) > 0
    t2 = 1.5*t2;
    x2 = cast(ceil(mu + t2*sd),cls);
end
if x >= x2
    y = ONE;
else
    % Scan backwards mu to find x1 such that binopdf(x1,n,p) == 0.
    t1 = cast(40,cls);
    x1 = cast(floor(mu - t1*sd),cls);
    while 0 < x1 && binopdf(x1,n,p) > eps(cls)
        t1 = 1.5*t1;
        x1 = cast(floor(mu - t1*sd),cls);
    end
    if x1 < 0
        x1 = ZERO;
    end
    if x < x1
        y = ZERO;
    else
        y = sumfrom(x1,x,n,p);
    end
end

%--------------------------------------------------------------------------
