function p = cdf(name,varargin)
%MATLAB Code Generation Library Function

%   Copyright 1993-2013 The MathWorks, Inc.
%#codegen

coder.internal.errorIf(nargin < 2,'stats:cdf:TooFewInputs');
coder.internal.prefer_const(name);
coder.internal.assert(eml_is_const(name),'Coder:toolbox:InputMustBeConstant','NAME');
coder.internal.errorIf(~ischar(name),'stats:cdf:BadDistribution');
nin = nargin - 1;
if strcmpi(name,'beta'),
    coder.internal.assert(nin <= 4,'MATLAB:maxrhs');
    p = betacdf(varargin{:});
elseif strcmpi(name,'bino') || strcmpi(name,'Binomial'),
    coder.internal.assert(nin <= 4,'MATLAB:maxrhs');
    p = binocdf(varargin{:});
elseif strcmpi(name,'chi2') || strcmpi(name,'Chisquare'),
    coder.internal.assert(nin <= 3,'MATLAB:maxrhs');
    p = chi2cdf(varargin{:});
elseif strcmpi(name,'exp') || strcmpi(name,'Exponential'),
    coder.internal.assert(nin <= 5,'MATLAB:maxrhs');
    p = expcdf(varargin{:});
elseif strcmpi(name,'ev') || strcmpi(name,'Extreme Value'),
    coder.internal.assert(nin <= 6,'MATLAB:maxrhs');
    p = evcdf(varargin{:});
elseif strcmpi(name,'f'),
    coder.internal.assert(nin <= 4,'MATLAB:maxrhs');
    p = fcdf(varargin{:});
elseif strcmpi(name,'gam') || strcmpi(name,'Gamma'),
    coder.internal.assert(nin <= 6,'MATLAB:maxrhs');
    p = gamcdf(varargin{:});
elseif strcmpi(name,'gev') || strcmpi(name,'Generalized Extreme Value'),
    coder.internal.assert(nin <= 5,'MATLAB:maxrhs');
    p = gevcdf(varargin{:});
elseif strcmpi(name,'gp') || strcmpi(name,'Generalized Pareto'),
    coder.internal.assert(nin <= 5,'MATLAB:maxrhs');
    p = gpcdf(varargin{:});
elseif strcmpi(name,'geo') || strcmpi(name,'Geometric'),
    coder.internal.assert(nin <= 3,'MATLAB:maxrhs');
    p = geocdf(varargin{:});
elseif strcmpi(name,'hyge') || strcmpi(name,'Hypergeometric'),
    coder.internal.assert(nin <= 5,'MATLAB:maxrhs');
    p = hygecdf(varargin{:});
elseif strcmpi(name,'logn') || strcmpi(name,'Lognormal'),
    coder.internal.assert(nin <= 6,'MATLAB:maxrhs');
    p = logncdf(varargin{:});
elseif strcmpi(name,'nbin') || strcmpi(name,'Negative Binomial'),
    coder.internal.assert(nin <= 4,'MATLAB:maxrhs');
    p = nbincdf(varargin{:});
elseif strcmpi(name,'ncf') || strcmpi(name,'Noncentral F'),
    coder.internal.assert(nin <= 5,'MATLAB:maxrhs');
    p = ncfcdf(varargin{:});
elseif strcmpi(name,'nct') || strcmpi(name,'Noncentral T'),
    coder.internal.assert(nin <= 4,'MATLAB:maxrhs');
    p = nctcdf(varargin{:});
elseif strcmpi(name,'ncx2') || strcmpi(name,'Noncentral Chi-square'),
    coder.internal.assert(nin <= 4,'MATLAB:maxrhs');
    p = ncx2cdf(varargin{:});
elseif strcmpi(name,'norm') || strcmpi(name,'Normal'),
    coder.internal.assert(nin <= 6,'MATLAB:maxrhs');
    p = normcdf(varargin{:});
elseif strcmpi(name,'poiss') || strcmpi(name,'Poisson'),
    coder.internal.assert(nin <= 3,'MATLAB:maxrhs');
    p = poisscdf(varargin{:});
elseif strcmpi(name,'rayl') || strcmpi(name,'Rayleigh'),
    coder.internal.assert(nin <= 3,'MATLAB:maxrhs');
    p = raylcdf(varargin{:});
elseif strcmpi(name,'t'),
    coder.internal.assert(nin <= 3,'MATLAB:maxrhs');
    p = tcdf(varargin{:});
elseif strcmpi(name,'unid') || strcmpi(name,'Discrete Uniform'),
    coder.internal.assert(nin <= 3,'MATLAB:maxrhs');
    p = unidcdf(varargin{:});
elseif strcmpi(name,'unif')  || strcmpi(name,'Uniform'),
    coder.internal.assert(nin <= 4,'MATLAB:maxrhs');
    p = unifcdf(varargin{:});
elseif strcmpi(name,'weib') || strcmpi(name,'Weibull') || strcmpi(name,'wbl')
    if strcmpi(name,'weib') || strcmpi(name,'Weibull')
        eml_warning('stats:cdf:ChangedParameters');
    end
    coder.internal.assert(nin <= 6,'MATLAB:maxrhs');
    p = wblcdf(varargin{:});
else
    coder.internal.errorIf(true,'Coder:toolbox:NotSupportedForCodegen',name);
end
