function [p,plo,pup] = evcdf(x,varargin)
%MATLAB Code Generation Library Function

%   Parameters: mu,sigma,pcov,alpha,upflag

%   Copyright 1993-2013 The MathWorks, Inc.
%#codegen

coder.internal.assert(nargin >= 1,'MATLAB:minrhs');
coder.internal.assert(nargin <= 6,'MATLAB:maxrhs');
validateattributes(x,{'single','double'},{'real'},'evcdf','x',1); %#ok<EMCA>
[upper,nparms] = CheckForUpper(varargin{:});
if nparms < 1
    mu = zeros(class(x));
else
    mu = varargin{1};
    validateattributes(mu,{'single','double'},{'real'},'evcdf','mu',2); %#ok<EMCA>
end
if nparms < 2
    sigma = ones(class(x));
else
    sigma = varargin{2};
    validateattributes(sigma,{'single','double'},{'real'},'evcdf','sigma',3); %#ok<EMCA>
end
% More checking if we need to compute confidence bounds.
CONFINT = nargout >= 2;
if CONFINT
    coder.internal.errorIf(nparms < 3, ...
        'stats:evcdf:MissedCov');
    pcov = varargin{3};
    coder.internal.assert(isequal(size(pcov),[2 2]), ...
        'stats:evcdf:BadShapedCovariance');
    if nparms < 4
        alpha = 0.05;
    else
        alpha = varargin{4};
        coder.internal.errorIf(~isnumeric(alpha) || ~isscalar(alpha) || ...
            alpha(1) <= 0 || alpha(1) >= 1,'stats:evcdf:BadAlpha');
    end
    normz = sqrt(2)*erfcinv(alpha); % -norminv(alpha/2);
end
p = coder.internal.sxalloc([true,true,true],x,mu,sigma);
if CONFINT
    plo = coder.nullcopy(p);
    pup = coder.nullcopy(p);
end
for k = 1:numel(p)
    xk = eml_scalexp_subsref(x,k);
    muk = eml_scalexp_subsref(mu,k);
    sigmak = eml_scalexp_subsref(sigma,k);
    if sigmak > 0
        zk = (xk - muk)/sigmak;
        p(k) = evcdfz(zk,upper);
        % Compute confidence bounds if requested.
        if CONFINT
            zvar = (pcov(1,1) + 2*pcov(1,2)*zk + pcov(2,2)*(zk*zk)) / ...
                (sigmak*sigmak);
            coder.internal.errorIf(zvar<0, ...
                'stats:evcdf:BadCovariance');
            halfwidth = normz*sqrt(zvar);
            zlo = zk - halfwidth;
            zup = zk + halfwidth;
            if upper
                plo(k) = evcdfz(zup,true);
                pup(k) = evcdfz(zlo,true);
            else
                plo(k) = evcdfz(zlo,false);
                pup(k) = evcdfz(zup,false);
            end
        end
    else
        p(k) = coder.internal.nan(class(p));
    end
end
