function [x,xlo,xup] = evinv(p,mu,sigma,pcov,alpha)
%MATLAB Code Generation Library Function

%   Copyright 1993-2013 The MathWorks, Inc.
%#codegen

coder.internal.assert(nargin >= 1,'stats:evinv:TooFewInputs');
if nargin < 2
    mu = zeros(class(p));
end
if nargin < 3
    sigma = ones(class(p));
end
validateattributes(p,{'single','double'},{'real'},'evinv','p',1); %#ok<EMCA>
validateattributes(mu,{'single','double'},{'real'},'evinv','mu',2); %#ok<EMCA>
validateattributes(sigma,{'single','double'},{'real'},'evinv','sigma',3); %#ok<EMCA>
CONFINT = nargout >= 2;
if CONFINT
    coder.internal.errorIf(nargin < 4, ...
        'stats:evinv:MissedCov');
    coder.internal.assert(isequal(size(pcov),[2 2]), ...
        'stats:evinv:BadShapedCovariance');
    if nargin < 5
        alpha = 0.05;
    else
        coder.internal.errorIf(~isnumeric(alpha) || ~isscalar(alpha) || ...
            alpha(1) <= 0 || alpha(1) >= 1,'stats:evinv:BadAlpha');
    end
    normz = sqrt(2)*erfcinv(alpha); % -norminv(alpha/2);
end
x = coder.internal.sxalloc([true,true,true],p,mu,sigma);
if CONFINT
    xlo = coder.nullcopy(x);
    xup = coder.nullcopy(x);
end
for k = 1:numel(x)
    pk = eml_scalexp_subsref(p,k);
    muk = eml_scalexp_subsref(mu,k);
    sigmak = eml_scalexp_subsref(sigma,k);
    if sigmak > 0 && pk >= 0 && pk <= 1
        if pk > 0
            pk = -log(1 - pk); % Could use -log1p(-pk) instead.
            if pk > 0
                q = log(pk);
            else % pk == 1
                q = coder.internal.inf(class(x));
            end
        else % pk == 0
            q = -coder.internal.inf(class(x));
        end
        x(k) = sigmak*q + muk;
        if CONFINT
            xvar = pcov(1,1) + 2*pcov(1,2)*q + pcov(2,2)*(q*q);
            coder.internal.errorIf(xvar < 0, ...
                'stats:evinv:BadCovariance');
            halfwidth = normz*sqrt(xvar);
            xlo(k) = x(k) - halfwidth;
            xup(k) = x(k) + halfwidth;
        end
    else
        x(k) = coder.internal.nan(class(x));
        if CONFINT
            xlo(k) = coder.internal.nan(class(x));
            xup(k) = coder.internal.nan(class(x));
        end
    end
end
