function [p,plo,pup] = expcdf(x,varargin)
%MATLAB Code Generation Library Function

%   Parameters: mu,pcov,alpha,tail

%   Copyright 1993-2013 The MathWorks, Inc.
%#codegen

coder.internal.assert(nargin >= 1,'stats:expcdf:TooFewInputsX');
coder.internal.assert(nargin <= 5,'MATLAB:maxrhs');
validateattributes(x,{'single','double'},{'real'},'expcdf','x',1); %#ok<EMCA>
[upper,nparms] = CheckForUpper(varargin{:});
if nparms < 1
    mu = ones(class(x));
else
    mu = varargin{1};
    validateattributes(mu,{'single','double'},{'real'},'expcdf','mu',2); %#ok<EMCA>
end
CONFINT = nargout >= 2;
if CONFINT
    coder.internal.errorIf(nparms < 2, ...
        'stats:expcdf:TooFewInputsVariance');
    pcov = varargin{2};
    coder.internal.assert(isscalar(pcov), ...
        'stats:expcdf:BadVarianceScalar');
    if nparms < 3
        alpha = 0.05;
    else
        alpha = varargin{3};
        coder.internal.errorIf(~isnumeric(alpha) || ~isscalar(alpha) || ...
            alpha(1) <= 0 || alpha(1) >= 1,'stats:expcdf:BadAlpha');
    end
    normz = sqrt(2)*erfcinv(alpha); % -norminv(alpha/2);
end
p = coder.internal.sxalloc([true,true],x,mu);
if CONFINT
    plo = coder.nullcopy(p);
    pup = coder.nullcopy(p);
end
for k = 1:numel(p)
    xk = eml_scalexp_subsref(x,k);
    muk = eml_scalexp_subsref(mu,k);
    if muk > 0 && ~isnan(xk)
        if xk < 0
            xk(1) = 0;
        end
        zk = xk/muk;
        if upper
            p(k) = exp(-zk);
        else
            p(k) = -expm1(-zk);
        end
        if CONFINT
            logzk = log(zk);
            coder.internal.errorIf(pcov(1) < 0, ...
                'stats:expcdf:BadVarianceNonNeg');
            halfwidth = normz*sqrt(pcov/(muk*muk));
            zlok = logzk - halfwidth;
            zupk = logzk + halfwidth;
            if upper
                plo(k) = evcdfz(zupk,true); % exp(-exp(zupk));
                pup(k) = evcdfz(zlok,true); % exp(-exp(zlok));
            else
                plo(k) = evcdfz(zlok,false); % -expm1(-exp(zlok));
                pup(k) = evcdfz(zupk,false); % -expm1(-exp(zupk));
            end
        end
    else
        p(k) = coder.internal.nan(class(p));
        if CONFINT
            plo(k) = coder.internal.nan(class(p));
            pup(k) = coder.internal.nan(class(p));
        end
    end
end
