function [x,xlo,xup] = expinv(p,mu,pcov,alpha)
%MATLAB Code Generation Library Function

%   Copyright 1993-2013 The MathWorks, Inc.
%#codegen

coder.internal.assert(nargin >= 1,'stats:expinv:TooFewInputsP');
if nargin < 2
    mu = ones(class(p));
end
validateattributes(p,{'single','double'},{'real'},'expinv','p',1); %#ok<EMCA>
validateattributes(mu,{'single','double'},{'real'},'expinv','mu',2); %#ok<EMCA>
CONFINT = nargout >= 2;
if CONFINT
    coder.internal.errorIf(nargin < 3, ...
        'stats:expinv:TooFewInputsVariance');
    coder.internal.assert(isscalar(pcov), ...
        'stats:expinv:BadVarianceScalar');
    if nargin < 4
        alpha = 0.05;
    else
        coder.internal.errorIf(~isnumeric(alpha) || ~isscalar(alpha) || ...
            alpha(1) <= 0 || alpha(1) >= 1,'stats:expinv:BadAlpha');
    end
    z = sqrt(2)*erfcinv(alpha); % -norminv(alpha/2);
end
x = coder.internal.sxalloc([true,true],p,mu);
if CONFINT
    xlo = coder.nullcopy(x);
    xup = coder.nullcopy(x);
end
for k = 1:numel(x)
    pk = eml_scalexp_subsref(p,k);
    muk = eml_scalexp_subsref(mu,k);
    if muk > 0 && pk >= 0 && pk <= 1
        if pk > 0
            if pk < 1
                x(k) = -muk*log(1 - pk); % Could use -muk*log1p(-pk).
            else % pk == 1
                x(k) = coder.internal.inf(class(pk));
            end
        else % pk == 0
            x(k) = zeros(class(pk));
        end
        if CONFINT
            % Work on extreme value scale (log scale).
            logxk = log(x(k));
            coder.internal.errorIf(pcov(1) < 0, ...
                'stats:expinv:BadVarianceNonNeg');
            halfwidth = z*sqrt(pcov/(muk*muk));
            % Convert back to Weibull scale
            xlo(k) = exp(logxk - halfwidth);
            xup(k) = exp(logxk + halfwidth);
        end
    else
        x(k) = coder.internal.nan(class(x));
        if CONFINT
            xlo(k) = coder.internal.nan(class(x));
            xup(k) = coder.internal.nan(class(x));
        end
    end
end
