function y = fpdf(x,v1,v2)
%MATLAB Code Generation Library Function

%   Copyright 1993-2013 The MathWorks, Inc.
%#codegen

coder.internal.assert(nargin == 3,'stats:fpdf:TooFewInputs');
validateattributes(x,{'single','double'},{'real'},'fpdf','x',1); %#ok<EMCA>
validateattributes(v1,{'numeric'},{'real'},'fpdf','v1',2); %#ok<EMCA>
validateattributes(v2,{'numeric'},{'real'},'fpdf','v2',3); %#ok<EMCA>
y = coder.internal.sxalloc([true,isfloat(v1),isfloat(v2)],x,v1,v2);
BIGV = 1e8;
for k = 1:numel(y)
    xk = eml_scalexp_subsref(x,k);
    v1k = cast(eml_scalexp_subsref(v1,k),class(y));
    v2k = cast(eml_scalexp_subsref(v2,k),class(y));
    if v1k > 0 && v2k > 0 && ~isnan(xk)
        if xk < 0 || isinf(xk)
            y(k) = 0;
        elseif isinf(v1k)
            if isinf(v2k)
                % If v1 is Inf AND v2 = Inf AND x is not NaN then set
                % fpdf(t,v1,v2) = 0 if t not equal to 1 and Inf if t = 1
                if xk == 1
                    y(k) = coder.internal.inf(class(y));
                else
                    y(k) = 0;
                end
            else
                % If v1 = Inf AND v2 is not Inf AND both v1, v2 > 0 AND x
                % is not NaN then fpdf(t,v1,v2) = (v2/t^2)*chi2pdf(
                % v2/t,v2)
                y(k) = v2k/(xk*xk)*chi2pdf(v2k/xk,v2k);
            end
        elseif isinf(v2k)
            % If v1 is not Inf AND v2 = Inf AND both v1, v2 > 0 AND x is
            % not NaN then fpdf(t,v1,v2) = v1*chi2pdf(v1*t,v1)
            y(k) = v1k*chi2pdf(v1k*xk,v1k);
        elseif xk == 0
            % Special case at x==0, result depends only on the value of v1
            if v1k > 2
                y(k) = 0;
            elseif v1k > 2
                y(k) = coder.internal.inf(class(y));
            else % if v1 == 2
                y(k) = 1;
            end
        elseif v1k > BIGV || v2k > BIGV
            y(k) = coder.internal.nan(class(y));
        else
            ratio = v1k*xk/v2k;
            logtemp = -log(xk) - 0.5*v1k*log1p(1/ratio) - ...
                0.5*v2k*log1p(ratio) - betaln(v1k/2,v2k/2);
            y(k) = exp(logtemp);
        end
    else
        % Special case for invalid parameters
        y(k) = coder.internal.nan(class(y));
    end
end