function [x,xlo,xup] = gaminv(p,a,b,pcov,alpha)
%MATLAB Code Generation Library Function

%   Copyright 1993-2013 The MathWorks, Inc.
%#codegen

coder.internal.assert(nargin >= 2,'stats:gaminv:TooFewInputs');
if nargin < 3
    b = ones(class(p));
end
validateattributes(p,{'single','double'},{'real'},'gaminv','p',1); %#ok<EMCA>
validateattributes(a,{'single','double'},{'real'},'gaminv','a',2); %#ok<EMCA>
validateattributes(b,{'single','double'},{'real'},'gaminv','b',3); %#ok<EMCA>
CONFINT = nargout >= 2;
if CONFINT
    coder.internal.errorIf(nargin < 4, ...
        'stats:gaminv:NeedCovariance');
    coder.internal.assert(isequal(size(pcov),[2 2]), ...
        'stats:gaminv:BadCovarianceSize');
    if nargin < 5
        alpha = 0.05;
    else
        coder.internal.errorIf(~isnumeric(alpha) || ~isscalar(alpha) || ...
            alpha(1) <= 0 || alpha(1) >= 1,'stats:gaminv:BadAlpha');
    end
end
x = coder.internal.sxalloc([true,true,true],p,a,b);
if CONFINT
    xlo = coder.nullcopy(x);
    xup = coder.nullcopy(x);
end
haswarned = false;
for k = 1:numel(x)
    pk = eml_scalexp_subsref(p,k);
    ak = eml_scalexp_subsref(a,k);
    bk = eml_scalexp_subsref(b,k);
    if 0 <= ak && ~isinf(ak) && 0 < bk && pk >= 0 && pk <= 1
        if pk > 0 && pk < 1 && ak > 0
            qk = real(gammaincinv(pk,ak));
            if ~haswarned && ...
                    abs(gammainc(qk,ak) - pk) > pk*sqrt(eps(class(qk)))
                eml_warning('stats:gaminv:NoConvergence', ...
                    coder.internal.flt2str(ak,4), ...
                    coder.internal.flt2str(bk,4), ...
                    coder.internal.flt2str(pk,4));
            end
            x(k) = qk*bk;
            if CONFINT
                logqk = log(qk);
                dqda = -dgammainc(qk,ak)/exp((ak-1)*logqk - qk - gammaln(ak));
                % Approximate the variance of x=q*b on the log scale.
                %    dlogx/da = dlogx/dq * dqda = dqda/q
                %    dlogx/db = 1/b
                logx = logqk + log(bk);
                dqdadq2 = dqda/qk;
                dqdadq2 = dqdadq2*dqdadq2;
                varlogx = pcov(1,1)*dqdadq2 + ...
                    2*pcov(1,2)*dqda/(bk*qk) + pcov(2,2)/(bk*bk);
                coder.internal.errorIf(varlogx < 0, ...
                    'stats:gaminv:BadCovariancePosDef');
                z = -norminv(alpha/2);
                halfwidth = z*sqrt(varlogx);
                % Convert back to original scale
                xlo(k) = exp(logx - halfwidth);
                xup(k) = exp(logx + halfwidth);
            end
        else
            if ak == 0 || pk == 0
                x(k) = 0;
            elseif pk == 1
                x(k) = coder.internal.inf(class(x));
            else
                x(k) = coder.internal.nan(class(x));
            end
            if CONFINT
                xlo(k) = x(k);
                xup(k) = x(k);
            end
        end
    else
        x(k) = coder.internal.nan(class(x));
        if CONFINT
            xlo(k) = coder.internal.nan(class(x));
            xup(k) = coder.internal.nan(class(x));
        end
    end
end
