function y = gampdf(x,a,b)
%MATLAB Code Generation Library Function

%   Copyright 1993-2013 The MathWorks, Inc.
%#codegen

coder.internal.assert(nargin >= 2,'stats:gampdf:TooFewInputs');
if nargin < 3
    b = ones(class(a));
end
validateattributes(x,{'single','double'},{'real'},'gampdf','x',1); %#ok<EMCA>
validateattributes(a,{'single','double'},{'real'},'gampdf','a',2); %#ok<EMCA>
validateattributes(b,{'single','double'},{'real'},'gampdf','b',3); %#ok<EMCA>
y = coder.internal.sxalloc([true,true,true],x,a,b);
for k = 1:numel(y)
    xk = eml_scalexp_subsref(x,k);
    ak = eml_scalexp_subsref(a,k);
    bk = eml_scalexp_subsref(b,k);
    if ak >= 0 && bk > 0 && ~isnan(xk)
        % Scale
        zk = xk/bk;
        % Special cases
        if zk == 0
            if ak < 1
                y(k) = coder.internal.inf(class(y));
            elseif ak > 1
                y(k) = 0;
            else
                % if ak == 1
                y(k) = 1/bk;
            end
        elseif zk < 0 || isinf(zk) || isinf(ak)
            y(k) = 0;
        elseif ak < 1
            y(k) = f(zk,ak)*exp(log(ak) - log(zk))/bk;
        else
            y(k) = f(zk,ak-1)/bk;
        end
    else
        y(k) = coder.internal.nan(class(y));
    end
end

%--------------------------------------------------------------------------

function y = f(z,a)
ZERO = eml_scalar_eg(z,a);
cls = class(ZERO);
y = coder.nullcopy(ZERO);
% Compute gampdf without error checking for z>0 and a>0.
if a <= realmin(cls)*z
    y(1) = exp(-z);
elseif z < realmin(cls)*a
    y(1) = exp(a*log(z) - z - gammaln(a + 1));
else
    lnsr2pi = cast(log(sqrt(2*pi)),cls);
    y(1) = exp(-lnsr2pi -0.5*log(a) - stirlerr(a) - binodeviance(a,z));
end

%--------------------------------------------------------------------------
