function [m,v] = gevstat(k,sigma,mu)
%MATLAB Code Generation Library Function

%   Copyright 1993-2013 The MathWorks, Inc.
%#codegen

coder.internal.assert(nargin == 3,'stats:gevstat:TooFewInputs');
validateattributes(k,{'single','double'},{'real'},'gevstat','k',1); %#ok<EMCA>
validateattributes(sigma,{'single','double'},{'real'},'gevstat','sigma',2); %#ok<EMCA>
validateattributes(mu,{'single','double'},{'real'},'gevstat','mu',3); %#ok<EMCA>
m = coder.internal.sxalloc([true,true,true],k,sigma,mu);
v = coder.nullcopy(m);
EC = -coder.internal.const(feval('psi',ones(class(m)))); % Euler's constant
PSI11 = coder.internal.const(pi*pi/6);
for j = 1:numel(m)
    sigmaj = eml_scalexp_subsref(sigma,j);
    muj = eml_scalexp_subsref(mu,j);
    kj = eml_scalexp_subsref(k,j);
    if sigmaj > 0 && ~(isnan(muj) || isnan(kj))
        abskj = abs(kj);
        if abskj < 1e-8
            m(j) = muj + EC*sigmaj;
            v(j) = PSI11*(sigmaj*sigmaj);
        elseif abskj < 5e-6;
            e1 = expm1(gammaln(1 - kj)); % gamma(1 - kj) - 1
            m(j) = muj + sigmaj*(e1/kj);
            v(j) = PSI11*(sigmaj*sigmaj);
        elseif kj < 0.5
            lngam1 = gammaln(1 - kj);
            e1 = expm1(lngam1); % gamma(1 - kj) - 1
            e2 = expm1(gammaln(1 - 2*kj)); % gamma(1 - 2*kj) - 1
            e3 = expm1(2*lngam1); % gamma(1 - kj)^2 - 1
            m(j) = muj + sigmaj*(e1/kj);
            v(j) = (e2 - e3)/(kj*kj)*(sigmaj*sigmaj);
        elseif kj < 1
            e1 = expm1(gammaln(1 - kj)); % gamma(1 - kj) - 1
            m(j) = muj + sigmaj*(e1/kj);
            v(j) = coder.internal.inf(class(v));
        else
            m(j) = coder.internal.inf(class(m));
            v(j) = coder.internal.inf(class(v));
        end
    else
        m(j) = coder.internal.nan(class(m));
        v(j) = coder.internal.nan(class(v));
    end
end
