function p = gpcdf(x,varargin)
%MATLAB Code Generation Library Function

%   Parameters: k,sigma,theta,tail
%   Copyright 1993-2013 The MathWorks, Inc.
%#codegen

coder.internal.assert(nargin >= 1,'stats:gpcdf:TooFewInputs');
coder.internal.assert(nargin <= 5,'MATLAB:maxrhs');
validateattributes(x,{'single','double'},{'real'},'gpcdf','x',1); %#ok<EMCA>
[upper,nparms] = CheckForUpper(varargin{:});
if nparms < 1
    k = zeros(class(x));
else
    k = varargin{1};
    validateattributes(k,{'single','double'},{'real'},'gpcdf','k',2); %#ok<EMCA>
end
if nparms < 2
    sigma = ones(class(x));
else
    sigma = varargin{2};
    validateattributes(sigma,{'single','double'},{'real'},'gpcdf','sigma',3); %#ok<EMCA>
end
if nparms < 3
    theta = zeros(class(x));
else
    theta = varargin{3};
    validateattributes(theta,{'single','double'},{'real'},'gpcdf','theta',4); %#ok<EMCA>
end
p = coder.internal.sxalloc([true,true,true,true],x,k,sigma,theta);
for j = 1:numel(p)
    xj = eml_scalexp_subsref(x,j);
    kj = eml_scalexp_subsref(k,j);
    sigmaj = eml_scalexp_subsref(sigma,j);
    thetaj = eml_scalexp_subsref(theta,j);
    if sigmaj > 0
        zj = (xj - thetaj)/sigmaj;
        if zj < 0
            p(j) = upper;
        elseif abs(kj) < eps(class(p))
            if upper
                p(j) = exp(-zj);
            else
                p(j) = -expm1(-zj);
            end
        else
            tj = zj*kj;
            if tj <= -1 && kj < -eps(class(p))
                p(j) = ~upper;
            else
                if upper
                    p(j) = exp(-log1p(tj)/kj); % (1 + z*k)^(-1/k)
                else
                    p(j) = -expm1(-log1p(tj)/kj); % 1 - (1 + z*k)^(-1/k)
                end
            end
        end
    else
        p(j) = coder.internal.nan(class(p));
    end
end
