function y = hygepdf(x,m,k,n)
%MATLAB Code Generation Library Function

%   Copyright 1993-2013 The MathWorks, Inc.
%#codegen

coder.internal.assert(nargin == 4,'stats:hygepdf:TooFewInputs');
validateattributes(x,{'single','double'},{'real'},'hygepdf','x',1); %#ok<EMCA>
validateattributes(m,{'numeric'},{'real'},'hygepdf','m',2); %#ok<EMCA>
validateattributes(k,{'numeric'},{'real'},'hygepdf','k',3); %#ok<EMCA>
validateattributes(n,{'numeric'},{'real'},'hygepdf','n',4); %#ok<EMCA>
y = coder.internal.sxalloc([true,isfloat(m),isfloat(k),isfloat(n)],x,m,k,n);
for j = 1:numel(y)
    xj = eml_scalexp_subsref(x,j);
    mj = cast(eml_scalexp_subsref(m,j),class(y));
    kj = cast(eml_scalexp_subsref(k,j),class(y));
    nj = cast(eml_scalexp_subsref(n,j),class(y));
    if mj >= 0 && kj >= 0 && nj >= 0 && floor(mj) == mj && ...
            floor(kj) == kj && floor(nj) == nj && ...
            nj <= mj && kj <= mj && ~isnan(xj)
        mjmkj = mj - kj;
        njmxj = nj - xj;
        if xj < 0 || mjmkj - njmxj + 1 <= 0 || floor(xj) ~= xj || ...
                xj > nj || xj > kj
            y(j) = 0;
        elseif nj == 0 || nj == mj
            y(j) = 1;
        else
            lnsqr2pi = cast(log(sqrt(2*pi)),class(y));
            % Get the biggest term for m-choose-n.
            % Use binomial pdf with p=n/m. Since p=n/m, binomial deviance is zero.
            p = nj/mj;
            onemp = 1 - p;
            mjmnj = mj - nj;
            kjmxj = kj - xj;
            mn = -lnsqr2pi - 0.5*log(nj*onemp) + ...
                stirlerr(mj) - stirlerr(nj) - stirlerr(mjmnj);
            if xj == 0
                kx = kj*log(onemp);
            elseif xj == kj
                kx = xj*log(p);
            else
                kx = -lnsqr2pi - 0.5*log(xj*(1 - xj/kj)) + ...
                    stirlerr(kj) - stirlerr(xj) - stirlerr(kjmxj) - ...
                    binodeviance(xj,kj*p) - ...
                    binodeviance(kjmxj,kj*onemp);
            end
            if nj == xj
                mknx = mjmkj*log(onemp);
            elseif njmxj == (mjmkj)
                mknx = njmxj*log(p);
            else
                tmp = mjmkj - njmxj;
                mknx = -lnsqr2pi - 0.5*log(njmxj*(1 - njmxj/mjmkj)) + ...
                    stirlerr(mjmkj) - stirlerr(njmxj) - stirlerr(tmp) - ...
                    binodeviance(njmxj,mjmkj*p) - ...
                    binodeviance(tmp,mjmkj*onemp);
            end
            y(j) = exp(kx + mknx - mn);
        end
    else
        y(j) = coder.internal.nan(class(y));
    end
end
