function y = nanvar(x,w,dim)
%MATLAB Code Generation Library Function

%   Copyright 1984-2013 The MathWorks, Inc.
%#codegen

coder.internal.assert(nargin > 0, ...
    'Coder:MATLAB:minrhs');
coder.internal.assert(isa(x,'float') || ischar(x), ...
    'Coder:toolbox:unsupportedClass','var',class(x));
% Set unsupplied arguments to default values.
if nargin < 3
    if eml_is_const(size(x)) && isequal(x,[]) % Special case.
        y = coder.internal.nan(class(x));
        return
    end
    coder.internal.assert(eml_is_const(size(x)) || ~isequal(x,[]), ...
        'Coder:toolbox:var_specialEmpty');
    dim = eml_const_nonsingleton_dim(x);
    coder.internal.assert(eml_is_const(size(x,dim)) || ...
        isscalar(x) || ...
        size(x,dim) ~= 1, ...
        'Coder:toolbox:autoDimIncompatibility');
    if nargin < 2
        w = cast(0,class(x));
    end
else
    coder.internal.prefer_const(dim);
    coder.internal.assert(eml_is_const(dim), ...
        'Coder:toolbox:dimNotConst');
    eml_assert_valid_dim(dim);
end
coder.internal.assert(isa(w,'float') || ischar(w), ...
    'Coder:toolbox:unsupportedClass','var',class(w));
% Recursive calls to regularize the input.
if eml_is_const(size(w)) && isempty(w)
    % Replace w with zero.
    y = nanvar(x,zeros(class(x)),dim);
    return
elseif ischar(x)
    if isscalar(w) || ischar(w)
        y = nanvar(double(x),double(w),dim);
    else
        y = nanvar(cast(x,class(w)),w,dim);
    end
    return
elseif ischar(w)
    y = nanvar(x,cast(w,class(x)),dim);
    return
end
% X and W are singles or doubles from this point onward.
n = coder.internal.indexInt(size(x,dim));
if eml_is_const(size(w)) && isscalar(w)
    % Unweighted variance
    % W is a flag, does not affect output class.
    yzero = eml_scalar_eg(real(x));
    coder.internal.assert(w == 0 || w == 1, ...
        'MATLAB:var:invalidWgts');
else
    coder.internal.assert(numel(w) == n, ...
        'MATLAB:var:invalidSizeWgts');
    % W is a weight vector, influences output class.
    yzero = eml_scalar_eg(real(x),w);
end
if eml_is_const(n) && n == 1 % Covers dim > ndims(x) case.
    % Generate NaNs with nonfinite inputs, otherwise zeros.
    y = yzero.*abs(x);
    return
end
sz = size(x);
sz(dim) = 1;
y = coder.nullcopy(zeros(sz,'like',yzero));
if ~isempty(y)
    % Compute variance.
    vstride = coder.internal.prodsize(x,'below',dim);
    vspread = (n - 1)*vstride;
    npages = coder.internal.prodsize(x,'above',dim);    
    ix = coder.internal.indexInt(0);
    iy = coder.internal.indexInt(0);
    for i = 1:npages
        for j = 1:vstride
            ix = ix + 1;
            iy = iy + 1;
            y(iy) = vector_variance(x,w,ix,vstride,n);
        end
        ix = ix + vspread;
    end
end

%--------------------------------------------------------------------------

function y = absdiff_squared(x,xbar)
% abs(x - xbar)^2
coder.inline('always');
if isreal(x) && isreal(xbar)
    r = x - xbar;
    y = r*r;
else
    c = x - xbar;
    cre = real(c);
    cim = imag(c);
    y = cre*cre + cim*cim;
end

%--------------------------------------------------------------------------

function y = vector_variance(x,w,ixstart,stride,n)
% Variance of the vector x(ixstart:stride:ixstart+(n-1)*stride)
% using denominator w if w is a scalar or weights if w is a vector.
% If isempty(x), the result is coder.internal.nan(class(x));
if isempty(x)
    y = coder.internal.nan(class(x)) + eml_scalar_eg(real(x),w);
elseif eml_is_const(size(w)) && isscalar(w)
    ix = ixstart;
    xbar = eml_scalar_eg(x);
    nn = coder.internal.indexInt(0);
    for k = 1:n
        if ~isnan(x(ix))
            xbar = xbar + x(ix);
            nn = nn + 1;
        end
        ix = ix + stride;
    end
    if nn == 0
        y = coder.internal.nan(class(x));
    else
        xbar = xbar/cast(nn,class(x));
        ix = ixstart;
        y = zeros(class(x));
        for k = 1:n
            if ~isnan(x(ix))
                y = y + absdiff_squared(x(ix),xbar);
            end
            ix = ix + stride;
        end
        if w == 0 && nn > 1
            nn = nn - 1;
        end
        y = y/cast(nn,class(x));
    end
else
    ix = ixstart;
    xbar = eml_scalar_eg(x);
    wsum = eml_scalar_eg(w);
    for k = 1:n
        if ~isnan(x(ix))
            xbar = xbar + w(k)*x(ix);
            wsum = wsum + w(k);
        end
        ix = ix + stride;
    end
    if wsum > 0 % implies nn > 0.
        xbar = xbar/wsum;
        ix = ixstart;
        y = zeros(class(x));
        for k = 1:n
            wk = w(k)/wsum;
            if ~isnan(x(ix))
                y = y + wk*absdiff_squared(x(ix),xbar);
            end
            ix = ix + stride;
        end
    else
        y = coder.internal.nan(class(x));
    end
end    

%--------------------------------------------------------------------------
