function p = ncfcdf(x,nu1,nu2,delta,tail)
%MATLAB Code Generation Library Function

%   Copyright 1993-2013 The MathWorks, Inc.
%#codegen

coder.internal.assert(nargin >= 4,'stats:ncfcdf:TooFewInputs');
validateattributes(x,{'single','double'},{'real'},'ncfcdf','x',1); %#ok<EMCA>
validateattributes(nu1,{'numeric'},{'real'},'ncfcdf','nu1',2); %#ok<EMCA>
validateattributes(nu2,{'numeric'},{'real'},'ncfcdf','nu2',3); %#ok<EMCA>
validateattributes(delta,{'single','double'},{'real'},'ncfcdf','delta',4); %#ok<EMCA>
if nargin < 5
    upper = false;
    tail = 'lower';
else
    coder.internal.prefer_const(tail);
    upper = CheckForUpper(tail);
end
p = coder.internal.sxalloc([true,isfloat(nu1),isfloat(nu2),true],x,nu1,nu2,delta);
cvgtol = eps(class(p))^0.75;
for k = 1:numel(p)
    xk = eml_scalexp_subsref(x,k);
    nu1k = cast(eml_scalexp_subsref(nu1,k),class(p));
    nu2k = cast(eml_scalexp_subsref(nu2,k),class(p));
    deltak = eml_scalexp_subsref(delta,k);
    if nu1k > 0 && nu2k > 0 && deltak >= 0 && ~isnan(xk)
        if xk > 0 && isinf(xk)
            p(k) = ~upper;
        elseif deltak == 0
            p(k) = fcdf(xk,nu1k,nu2k,tail);
        elseif xk <= 0
            p(k) = upper;
        else
            % to simplify computation, pre-divide nu1,nu2 and delta
            nu1k = nu1k/2;
            nu2k = nu2k/2;
            deltak = deltak/2;
            %Value passed to Beta distribution function.
            tmp = nu1k*xk/(nu2k + nu1k*xk);
            logtmp = log(tmp);
            nu2const = nu2k*log(1 - tmp) - localgammaln(nu2k);
            % Sum the series.  The general idea is that we are going to sum
            % terms of the form
            %        poisspdf(j,delta) .* betacdf(tmp,j+nu1,nu2)
            % We will save some time by computing these pdf and cdf
            % functions once at a point that we hope will be near the
            % maximum of the series, and we will compute other terms in the
            % series using recurrence relations.
            j0 = floor(deltak); % start from here
            % Compute Poisson pdf and beta cdf at the starting point
            ppdf0 = cast( ...
                exp(-deltak + j0*log(deltak) - localgammaln(j0 + 1)), ...
                class(p)); % Does not involve nu1, nu2, or xk, so cast.
            if upper
                bcdf0 = real(betainc(tmp,j0 + nu1k,nu2k,'upper'));
            else
                bcdf0 = betacdf(tmp,j0 + nu1k,nu2k);
            end
            % Set up for loop over values less than j0
            y = ppdf0*bcdf0;
            ppdf = ppdf0;
            bcdf = bcdf0;
            olddy = zeros(class(p));
            j = j0 - 1;
            if j >= 0
                while true
                    % Use recurrence relation to compute new pdf and cdf
                    ppdf = ppdf*(j + 1)/deltak;
                    if upper
                        bcdf = real(betainc(tmp,j + nu1k,nu2k,'upper'));
                    else
                        db = exp((j + nu1k)*logtmp + nu2const + ...
                            localgammaln(j + nu1k + nu2k) - ...
                            localgammaln(j + nu1k + 1));
                        bcdf = bcdf + db;
                    end
                    deltay = ppdf*bcdf;
                    y = y + deltay;
                    j = j - 1;
                    % Convergence test:  change must be small and not increasing
                    if ~(deltay > y*cvgtol || abs(deltay) > olddy) || ~(j >= 0)
                        break
                    end
                    olddy = abs(deltay);
                end
            end
            % Set up again for loop upward from j0
            ppdf = ppdf0;
            bcdf = bcdf0;
            olddy = zeros(class(p));
            j = j0 + 1;
            noconvergence = true;
            for jj = 1:5000 % so that we don't get into an infinite loop
                ppdf = ppdf*deltak/j;
                if upper
                    bcdf = real(betainc(tmp,j + nu1k,nu2k,'upper'));
                else
                    bcdf = bcdf - exp((j + nu1k - 1)*logtmp + nu2const + ...
                        localgammaln(j + nu1k + nu2k - 1) - ...
                        localgammaln(j + nu1k));
                end
                deltay = ppdf*bcdf;
                % ok = indices not converged
                y = y + deltay;
                % Convergence test:  change must be small and not increasing
                if ~(deltay > y*cvgtol || abs(deltay) > olddy)
                    noconvergence = false;
                    break
                end
                olddy = abs(deltay);
                j = j + 1;
            end
            if noconvergence
                eml_warning('stats:ncfcdf:NoConvergence');
            end
            p(k) = y;
        end
    else
        % Special case for invalid parameters
        p(k) = coder.internal.nan(class(p));
    end
end

%--------------------------------------------------------------------------

function x = localgammaln(y)
x = gammaln(max(zeros(class(y)),y));

%--------------------------------------------------------------------------
