function x = nctinv(p,nu,delta)
%MATLAB Code Generation Library Function

%   Copyright 1993-2013 The MathWorks, Inc.
%#codegen

coder.internal.assert(nargin == 3,'stats:nctinv:TooFewInputs');
validateattributes(p,{'single','double'},{'real'},'nctinv','p',1); %#ok<EMCA>
validateattributes(nu,{'numeric'},{'real'},'nctinv','nu',2); %#ok<EMCA>
validateattributes(delta,{'single','double'},{'real'},'nctinv','delta',3); %#ok<EMCA>
x = coder.internal.sxalloc([true,isfloat(nu),true],p,nu,delta);
crit = sqrt(eps(class(x)));
haswarned = false;
for k = 1:numel(x)
    pk = eml_scalexp_subsref(p,k);
    vk = cast(eml_scalexp_subsref(nu,k),class(x));
    dk = eml_scalexp_subsref(delta,k);
    if vk > 0 && ~isnan(dk) && pk >= 0 && pk <= 1
        if pk == 0
            x(k) = -coder.internal.inf(class(x));
        elseif pk == 1
            x(k) = coder.internal.inf(class(x));
        elseif dk == 0
            x(k) = tinv(pk,vk);
        else
            % Newton's Method.
            % Permit no more than count_limit iterations.
            count_limit = 100;
            count = 0;
            % Use delta as a starting guess for x.
            xk = cast(dk,class(x));
            h = ones(class(x));
            % Break out of the iteration loop for the following:
            %  1) The last update is very small (compared to x or in abs. value).
            %  2) There are more than 100 iterations.
            F =  nctcdf(xk,vk,dk);
            absxk = abs(xk);
            while abs(h) > crit*max(1,absxk) && count < count_limit
                count = count + 1;
                f =  nctpdf(xk,vk,dk);
                h = (F - pk)/f;
                % Avoid stepping too far
                xnew = max(-5*absxk,min(5*absxk,xk - h));
                % Back off if the step gives a worse result
                Fnew = nctcdf(xnew,vk,dk);
                while true
                    if abs(Fnew - pk) <= abs(F - pk)*(1 + crit) || ...
                            abs(xk - xnew) <= crit*absxk
                        break
                    end
                    xnew = 0.5*(xnew + xk);
                    Fnew = nctcdf(xnew,vk,dk);
                end
                xk = xnew;
                absxk = abs(xk);
                F = Fnew;
            end
            % Return the converged value(s).
            x(k) = xk;
            if ~haswarned && count == count_limit
                haswarned = true;
                eml_warning('stats:nctinv:NoConvergence',eml_flt2str(abs(h),5));
            end
        end
    else
        x(k) = coder.internal.nan(class(x));
    end
end

