function [dy,y,d2y] = dgammainc(x,a,tail)
%MATLAB Code Generation Private Function

%   Copyright 1993-2013 The MathWorks, Inc.
%#codegen

coder.internal.assert(nargin >= 2, 'MATLAB:minrhs');
coder.internal.prefer_const(a);
if nargin < 3
    lower = true;
else
    coder.internal.prefer_const(tail);
    lower = strcmp(tail,'lower');
    coder.internal.assert(lower || strcmp(tail,'upper'), ...
        'stats:dgammainc:InvalidTailArg');
end
dy = coder.internal.sxalloc([true,true],x,a);
y = coder.nullcopy(dy);
d2y = coder.nullcopy(dy);
ZERO = zeros(class(dy));
ONE = ones(class(dy));
% Upper limit for series and continued fraction.
amax = 2^20;
for k = 1:numel(dy)
    xk = eml_scalexp_subsref(x,k);
    ak = eml_scalexp_subsref(a,k);
    if xk >= 0 && ak >= 0
        if ak > amax
            % Approximation for a > amax.  Accurate to about 5.e-5.
            xk(1) = max(amax-1/3 + sqrt(amax/ak)*(xk-(ak-1/3)),ZERO);
            ak(1) = amax;
        end
        if xk == 0
            if ak == 0
                if lower
                    y(k) = ONE;
                    dy(k) = -coder.internal.inf(class(dy));
                    d2y(k) = coder.internal.inf(class(dy));
                else
                    y(k) = ZERO;
                    dy(k) = coder.internal.inf(class(dy));
                    d2y(k) = -coder.internal.inf(class(dy));
                end
            else
                if lower
                    y(k) = ZERO;
                else
                    y(k) = ONE;
                end
                dy(k) = ZERO;
                d2y(k) = ZERO;
            end
        elseif xk < ak + 1
            [y(k),dy(k),d2y(k)] = iterate1(xk,ak,lower);
        else % if xk >= ak + 1
            [y(k),dy(k),d2y(k)] = iterate2(xk,ak,lower);
        end
    else
        coder.internal.errorIf(ak < 0,'stats:dgammainc:NegativeArg');
        % The non-codegen version allows xk < 0 but returns complex
        % results. At present we do not need this functionality, and it
        % presents complications for code generation, so we return NaN.
        dy(k) = coder.internal.nan(class(dy));
        y(k) = coder.internal.nan(class(dy));
        d2y = coder.internal.nan(class(dy));
    end
end

%--------------------------------------------------------------------------

function [yk,dyk,d2yk] = xform(xk,ak,g,dg,d2g,flip)
coder.inline('always');
coder.internal.prefer_const(ak,flip);
ZERO = eml_scalar_eg(xk,ak);
ONE = ZERO + 1;
fac = exp(-xk + ak*log(xk) - gammaln(ak+1));
yk = fac*g;
dlogfac = (log(xk) - psi(ak+1));
dfac = fac*dlogfac;
dyk = dfac*g + fac*dg;
d2fac = dfac*dlogfac - fac*psi(1,ak+1);
d2yk = d2fac*g + 2*dfac*dg + fac*d2g;
% Make minor adjustments in special cases to zero round-off error.
if xk > 0 && yk > 1
    yk = ones(class(yk));
end
if ak == 0
    % Force exact result for yk.
    if flip
        yk = ONE;
    else
        yk = ZERO;
    end
end
if flip
    yk = ONE - yk;
    dyk = -dyk;
    d2yk = -d2yk;
end

%--------------------------------------------------------------------------

function [yk,dyk,d2yk] = iterate1(xk,ak,lower)
% Series expansion for lower incomplete gamma when x < a+1
coder.inline('always');
coder.internal.prefer_const(ak,lower);
ZERO = eml_scalar_eg(xk,ak);
ONE = ZERO + 1;
aplusn = ak;
del = ONE;
ddel = ZERO;
d2del = ZERO;
sum = del;
dsum = ddel;
d2sum = d2del;
while norm(del,'inf') >= 100*eps(norm(sum,'inf'))
    aplusn = aplusn + 1;
    del = del*xk/aplusn;
    ddel = (ddel*xk - del)/aplusn;
    d2del = (d2del*xk - 2*ddel)/aplusn;
    sum = sum + del;
    dsum = dsum + ddel;
    d2sum = d2sum + d2del;
end
[yk,dyk,d2yk] = xform(xk,ak,sum,dsum,d2sum,~lower);

%--------------------------------------------------------------------------

function [yk,dyk,d2yk] = iterate2(xk,ak,lower)
% Continued fraction for upper incomplete gamma when x >= a+1
coder.inline('always');
coder.internal.prefer_const(ak,lower);
ZERO = eml_scalar_eg(xk,ak);
ONE = ZERO + 1;
n = ZERO;
a0 = ZERO;
a1 = ak;
b0 = ONE;
b1 = xk;
da0 = ZERO;
db0 = ZERO;
da1 = ONE;
db1 = ZERO;
d2a0 = ZERO;
d2b0 = ZERO;
d2a1 = ZERO;
d2b1 = ZERO;
g = ak/xk;
dg = 1/xk;
d2g = ZERO;
d2gold = ONE; % force one iteration, any nonzero value will do
% Testing d2g is the more stringent than testing g or dg.  d2g may
% be zero, so use a strict inequality
while norm(d2g-d2gold,'inf') > 100*eps(norm(d2g,'inf'))
    rescale = 1/b1; % keep terms from overflowing
    n = n + 1;
    nminusa = n - ak;
    d2a0 = (d2a1 + d2a0*nminusa - 2*da0)*rescale;
    d2b0 = (d2b1 + d2b0*nminusa - 2*db0)*rescale;
    da0 = (da1 + da0*nminusa - a0)*rescale;
    db0 = (db1 + db0*nminusa - b0)*rescale;
    a0 = (a1 + a0*nminusa)*rescale;
    b0 = 1 + (b0*nminusa)*rescale; % (b1 + b0*nminusa)*rescale
    nrescale = n*rescale;
    d2a1 = d2a0*xk + d2a1*nrescale;
    d2b1 = d2b0*xk + d2b1*nrescale;
    da1 = da0*xk + da1*nrescale;
    db1 = db0*xk + db1*nrescale;
    a1 = a0*xk + a1*nrescale;
    b1 = b0*xk + n; % b0*xk + b1*nrescale
    d2gold = d2g;
    g = a1/b1;
    dg = (da1 - g*db1)/b1;
    d2g = (d2a1 - dg*db1 - g*d2b1 - dg*db1)/b1;
end
[yk,dyk,d2yk] = xform(xk,ak,g,dg,d2g,lower);

%--------------------------------------------------------------------------
