function [y,c] = nan_sum_or_mean(op,x,dim)
%MATLAB Code Generation Library Function

%   Copyright 1993-2013 The MathWorks, Inc.
%#codegen

coder.internal.errorIf(nargin < 2,'MATLAB:minrhs');
coder.internal.prefer_const(op);
DOMEAN = coder.internal.const(strcmp(op,'mean'));
DOCOUNT = DOMEAN || nargout == 2;
XZERO = eml_scalar_eg(x);
if isfloat(x)
    NAN = coder.internal.nan(class(x)) + XZERO; % Make complex if needed.
else
    NAN = XZERO;
end
% Determine the dimension over which to perform the operation.
if nargin < 3
    if eml_is_const(size(x)) && isequal(size(x),[0,0])
        if DOMEAN
            y = NAN;
        else
            y = XZERO;
        end
        return
    end
    coder.internal.assert(eml_is_const(size(x)) || ~isequal(x,[]), ...
        'Coder:toolbox:sum_specialEmpty');
    idim = eml_const_nonsingleton_dim(x);
    coder.internal.assert(eml_is_const(size(x,idim)) || ...
        isscalar(x) || ...
        size(x,idim) ~= 1, ...
        'Coder:toolbox:autoDimIncompatibility');
else
    coder.internal.prefer_const(dim);
    coder.internal.assert(eml_is_const(dim), ...
        'Coder:toolbox:dimNotConst');
    eml_assert_valid_dim(dim);
    idim = coder.internal.indexInt(dim);
end
if eml_is_const(size(x,idim)) && size(x,idim) == 1 % Covers dim > ndims(x) case.
    y = x;
    c = ones(size(x),coder.internal.indexIntClass);
    for k = 1:numel(x)
        if isnan(x(k))
            c(k) = 0;
            if DOMEAN
                y(k) = NAN;
            else
                y(k) = 0;
            end
        end
    end
    return
end
IZERO = coder.internal.indexInt(0);
IONE = coder.internal.indexInt(1);
sz = size(x);
sz(idim) = 1;
y = coder.nullcopy(zeros(sz,'like',XZERO));
c = zeros(sz,coder.internal.indexIntClass);
if isempty(x)
    if DOMEAN
        y(:) = NAN;
    else
        y(:) = XZERO;
    end
elseif eml_is_const(isscalar(y)) && isscalar(y)
    vlen = coder.internal.indexInt(numel(x));
    y = XZERO;    
    if DOCOUNT || nargout == 2
        c = IZERO;
    end
    for k = 1:vlen;
        if ~isnan(x(k))
            y = y + x(k);
            if DOCOUNT
                c = c + 1;
            end
        end
    end
    if DOMEAN
        if c == 0
            y = NAN;
        else
            y = y / cast(c,class(x));
        end
    end
else
    vlen = coder.internal.indexInt(size(x,idim));
    vstride = coder.internal.prodsize(x,'below',idim);
    npages = coder.internal.prodsize(x,'above',idim);
    ix = IZERO;
    iy = IZERO;
    for i = 1:npages
        ixstart = ix;
        for j = 1:vstride
            ixstart = ixstart + 1;
            ix = ixstart;
            if ~isnan(x(ix))
                s = x(ix);
                if DOCOUNT
                    n = IONE;
                end
            else
                s = XZERO;
                if DOCOUNT
                    n = IZERO;
                end
            end
            for k = 2:vlen
                ix = ix + vstride;
                if ~isnan(x(ix))
                    s = s + x(ix);
                    if DOCOUNT
                        n = n + 1;
                    end
                end
            end
            if DOMEAN
                if n == 0
                    s = NAN;
                else
                    s = s / cast(n,class(x));
                end
            end
            iy = iy + 1;
            y(iy) = s;
            if DOCOUNT
                c(iy) = n;
            end
        end
    end
end
