function s = skewness(x,flag,dim)
%MATLAB Code Generation Toolbox Function

%   Copyright 1993-2013 The MathWorks, Inc.
%#codegen

coder.internal.assert(nargin > 0,'MATLAB:minrhs');
if nargin == 3
    % We will not support an empty dim input.
    coder.internal.prefer_const(dim);
    if isempty(flag)
        s = skewness(x,true,dim);
        return
    end
    eml_assert_valid_dim(dim);
else
    if eml_is_const(size(x)) && isequal(size(x),[0,0])
        s = coder.internal.nan(class(x));
        return
    end
    dim = eml_const_nonsingleton_dim(x);
    if nargin == 1
        flag = 1;
    end
    if eml_is_const(size(x)) && isequal(x,[])
        s = coder.internal.nan(class(x));
        return
    end
end
if isempty(x)
    s = coder.nullcopy(sum(x,dim)); % Gets size and class.
    s(:) = coder.internal.nan(class(s)); % Sets values.
    return
end
% Center X, compute its third and second moments, and compute the
% uncorrected skewness. First call to nanmean goes directly to
% nan_sum_or_mean to get the non-nan count output.
[m1,n] = nan_sum_or_mean('mean',x,dim);
x0 = bsxfun(@minus,x,m1);
xp = x0.*x0;
s2 = nanmean(xp,dim); % this is the biased variance estimator
xp = xp.*x0;
m3 = nanmean(xp,dim);
s = m3./(s2.^1.5);
if flag == 0
    % Bias correct the skewness.
    for j = 1:numel(s)
        if n(j) >= 3
            nj = cast(n(j),class(s));
            s(j) = s(j)*sqrt((nj - 1)/nj)*nj/(nj - 2);
        else
            % bias correction is not defined for n < 3.
            s(j) = coder.internal.nan(class(s));
        end
    end
end
