function p = tcdf(x,v,tail)
%MATLAB Code Generation Library Function

%   Copyright 1993-2013 The MathWorks, Inc.
%#codegen

coder.internal.assert(nargin >= 2,'stats:tcdf:TooFewInputs');
validateattributes(x,{'single','double'},{'real'},'tcdf','x',1); %#ok<EMCA>
validateattributes(v,{'numeric'},{'real'},'tcdf','v',2); %#ok<EMCA>
if nargin < 3
    upper = false;
else
    coder.internal.prefer_const(tail);
    upper = CheckForUpper(tail);
end
p = coder.internal.sxalloc([true,isfloat(v)],x,v);
for k = 1:numel(p)
    if upper
        xk = -eml_scalexp_subsref(x,k);
    else
        xk = eml_scalexp_subsref(x,k);
    end
    vk = eml_scalexp_subsref(v,k);
    if vk > 0 && ~isnan(xk)
        if xk == 0 % Make the result exact for the median.
            p(k) = 0.5;
        elseif vk > 1e7
            % Normal Approximation for very large nu.
            p(k) = normcdf(xk);
        elseif vk == 1
            % Special case for Cauchy distribution.  See Devroye pages 29 and 450.
            % Note that instead of the usual Cauchy formula (atan x)/pi + 0.5,
            % we use acot(-x), which is equivalent and avoids roundoff error.
            p(k)  = acot(-xk)/pi;
            if xk > 0
                p(k) = p(k) + 1;
            end
        else
            % General case: first compute F(-|x|) < .5, the lower tail. See
            % Abramowitz and Stegun, formulas and 26.7.1/26.5.27 and 26.5.2
            vf = cast(vk,class(p));
            xsq = xk*xk;
            if vf < xsq % For small v, form v/(v+x^2) to maintain precision
                p(k) = real(betainc(vf/(vf + xsq),vf/2,0.5,'lower'))/2;
            else % For large v, form x^2/(v+x^2) to maintain precision
                p(k) = real(betainc(xsq/(vf + xsq),0.5,vf/2,'upper'))/2;
            end
            if xk > 0 % For x > 0, F(x) = 1 - F(-|x|).
                p(k) = 1 - p(k);
            end
        end
    else
        p(k) = coder.internal.nan(class(p));
    end
end
