function [p,plo,pup] = wblcdf(x,varargin)
%MATLAB Code Generation Library Function

%   Parameters: A,B,pcov,alpha,tail

%   Copyright 1993-2013 The MathWorks, Inc.
%#codegen

coder.internal.assert(nargin >= 1,'MATLAB:minrhs');
coder.internal.assert(nargin <= 6,'MATLAB:maxrhs');
validateattributes(x,{'single','double'},{'real'},'wblcdf','x',1); %#ok<EMCA>
[upper,nparms] = CheckForUpper(varargin{:});
if nparms < 1
    A = 1;
else
    A = varargin{1};
    validateattributes(A,{'single','double'},{'real'},'wblcdf','A',2); %#ok<EMCA>
end
if nparms < 2
    B = 1;
else
    B = varargin{2};
    validateattributes(B,{'single','double'},{'real'},'wblcdf','B',3); %#ok<EMCA>
end
% More checking if we need to compute confidence bounds.
CONFINT = nargout >= 2;
if CONFINT
    coder.internal.errorIf(nparms < 3, ...
        'stats:wblcdf:MustProvideCovMatrix');
    pcov = varargin{3};
    coder.internal.assert(isequal(size(pcov),[2 2]), ...
        'stats:wblcdf:BadCovariance');
    if nparms < 4
        alpha = 0.05;
    else
        alpha = varargin{4};
        coder.internal.errorIf(~isnumeric(alpha) || ~isscalar(alpha) || ...
            alpha(1) <= 0 || alpha(1) >= 1,'stats:wblcdf:BadAlpha');
    end
    normz = sqrt(2)*erfcinv(alpha); % -norminv(alpha/2);
end
p = coder.internal.sxalloc([true,true,true],x,A,B);
if CONFINT
    plo = coder.nullcopy(p);
    pup = coder.nullcopy(p);
end
for k = 1:numel(p)
    xk = eml_scalexp_subsref(x,k);
    Ak = eml_scalexp_subsref(A,k);
    Bk = eml_scalexp_subsref(B,k);
    if Ak > 0 && Bk > 0 && ~isnan(xk)
        if xk < 0
            p(k) = upper;
            if CONFINT
                plo(k) = upper;
                pup(k) = upper;
            end
        else
            zk = (xk/Ak)^Bk;
            if upper
                p(k) = exp(-zk);
            else
                p(k) = -expm1(-zk);
            end
            if CONFINT
                % Work on extreme value scale (log scale).
                logz = log(zk);
                dA = 1/Ak;
                dB = -1/(Bk*Bk);
                dBlogz = dB*logz;
                logzvar = (pcov(1,1)*(dA*dA) + 2*pcov(1,2)*dA*dB*logz + pcov(2,2)*(dBlogz*dBlogz))*(Bk*Bk);
                %    deriv = [1./A, -1./(B.^2)];
                %    pcov = pcov .* (deriv' * deriv);
                %    logzvar = (pcov(1,1) + 2*pcov(1,2)*logz + pcov(2,2)*logz.^2) .* (B.^2);
                coder.internal.errorIf(logzvar < 0, ...
                    'stats:wblcdf:BadCovariance');
                halfwidth = normz*sqrt(logzvar);
                zlo = logz - halfwidth;
                zup = logz + halfwidth;
                % Convert back to Weibull scale
                if upper
                    plo(k) = evcdfz(zup,true); % exp(-exp(zup));
                    pup(k) = evcdfz(zlo,true); % exp(-exp(zlo));
                else
                    plo(k) = evcdfz(zlo,false); % -expm1(-exp(zlo));
                    pup(k) = evcdfz(zup,false); % -expm1(-exp(zup));
                end
            end
        end
    else
        p(k) = coder.internal.nan(class(p));
        if CONFINT
            plo(k) = coder.internal.nan(class(p));
            pup(k) = coder.internal.nan(class(p));
        end
    end
end
